春光乍泄 (豆瓣)
Description: 春光乍泄电影简介和剧情介绍,春光乍泄影评、图片、预告片、影讯、论坛、在线购票
Keywords: 春光乍泄,春光乍洩,春光乍泄影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.86豆瓣电影Top250

# 春光乍泄 春光乍洩 (1997)

导演: 王家卫
编剧: 王家卫
主演: 张国荣 / 梁朝伟 / 张震 / 格利高里·戴顿
类型: 剧情 / 爱情 / 同性
制片国家/地区: 中国香港 / 日本 / 韩国
语言: 粤语 / 汉语普通话 / 西班牙语
上映日期: 1997-05-30(中国香港) / 1997-05-17(戛纳电影节)
片长: 96分钟
又名: 一起快乐 / Happy Together / Buenos Aires Affair
IMDb: tt0118845
豆瓣评分
引用
9.0
598446人评价
5星
57.8%
4星
33.8%
3星
7.6%
2星
0.6%
1星
0.2%
想看 看过
评价:
推荐

## 春光乍泄的剧情简介 · · · · · ·

黎耀辉（梁朝伟）与何宝荣（张国荣）是一对同性恋人，为了有新的开始，他们怀着美丽的梦想（去看南美洲大瀑布）离开香港来到阿根廷，却在布宜诺斯艾利斯迷了路。黎耀辉想安下心来过日子，无奈何宝荣于夜夜笙歌中放纵着自己的生命，以期找寻更多的刺激，只当黎耀辉是他受伤后的港湾，两人分歧 、争吵越来越多，心的距离越来越远。
黎耀辉明白过去的日子不可能再复返时，决定离开何宝荣，而正是在他离开后，绝望的意味（对黎耀辉的爱）才在何宝荣的脑海中完整地浮现。 ©豆瓣

## 春光乍泄的演职员 · · · · · · ( 全部 19 )

- 王家卫 导演
- 张国荣 饰 何宝荣
- 梁朝伟 饰 黎耀辉
- 张震 饰 张宛
- 格利高里·戴顿 饰 情人
- 彭绮华 制片人

## 春光乍泄的视频和图片 · · · · · · ( 预告片3 | 视频评论1 · 添加 | 图片2414 · 添加 )

## 春光乍泄的获奖情况 · · · · · · ( 全部 )

- 第50届戛纳电影节
- 主竞赛单元 金棕榈奖(提名)
- 王家卫

- 第34届台北金马影展
- 金马奖 最佳导演(提名)
- 王家卫

- 第17届香港电影金像奖
- 最佳电影(提名)
- 王家卫

## 喜欢这部电影的人也喜欢 · · · · · ·

  蓝宇

  断背山

  重庆森林

  花样年华

  请以你的名字呼唤我

  喜宴

  霸王别姬

  阿飞正传

  谁先爱上他的

  甜蜜蜜

我要写短评

## 春光乍泄的短评 · · · · · · ( 全部 134200 条 )

热门 / 最新 / 好友

### 19290 有用 LisaLeung 看过 2011-01-21 19:48:19

张国荣死后，有一个女荣迷，在网上发了一片贴子，说到自己看到梁朝伟的情形，有一次梁朝伟到内地来演出，等演出完毕后她守在他出门的必经之路，等看到他和一群人走来，她便大声的哭喊道：“黎耀辉，你还记不记得何宝荣？”梁朝伟听到她的喊叫，停下来，朝她这个方向看来，然后点了点头，急匆匆地走了

### 13704 有用 同志亦凡人中文站 看过 2014-04-02 09:28:50

何宝荣。黎耀辉。如果你对一个人有特别的感情，你会更喜欢叫他的全名。

### 8272 有用 色狼猫 看过 2010-11-10 19:58:26

光棍节给自己准备的电影《春光乍泄》，根本就是找虐。。。。黎耀辉简直是八心八箭4个9的纯GAY，极品中的极品，GAY中的爱马仕，GAY中的劳力士，GAY中的劳斯莱斯，上下5000年不可多得的尤物！！！我想变男人要这样的男朋友啊啊啊啊

### 8360 有用 隆咚锵 看过 2007-02-26 01:06:58

爱一个男的还是爱一个女的尤其的不重要，只是爱一个爱上了的人……这个世界就完了

### 1580 有用 刘大顺！ 看过 2010-04-10 20:58:31

张国荣转过身抽烟的样子看的我酥掉了=。=

> 更多短评 134200条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 春光乍泄的影评 · · · · · · ( 全部 2782 条 )

热门 / 最新 / 好友
布宜諾斯 2005-11-06 13:01:01

## 电影美学的极致

如果说文学语言的特性体现在文字上，舞蹈语言的特性体现在身体造型上，那么,，影视语言特性则体现在画面、声音及声画合一的蒙太奇中。香港导演王家卫1997年的作品《春光乍泄》既是电影语言表达到一个极至的代表。这部曾在法国嘎那电影节上惊艳于世界的影片，算得上在叙事、剪接... (展开)
7945 304 262回应 收起
dearalice 2009-08-05 20:36:25

## 他以为，这个世界总有个人等他回来

这篇影评可能有剧透

影片的最后。 黎耀辉说，在返香港之前我在台北住了一个晚上，我到了辽宁街，夜市很热闹，我没见着小张，只看见他家人，我终于明白他可以开开心心在外边走来走去的原因，他知道自己有处地方让他回去。 我突然明白，为何何宝荣可以一次又一次毫不顾忌地离开黎耀辉，去外面的世界... (展开)
7780 135 444回应 收起
海岸 2005-11-17 13:22:11

## 黎耀辉，你还记不记得何宝荣？

看了《春光乍泄》之后，我在网上把剧情讲给网友听，我在屏幕上一行一行不停地打着字，等打完了，过了一会儿，她才慢慢的回过来一句话：“隔着屏幕，我都能感觉到你的悲伤……” 张国荣死后，有一个女荣迷，在网上发了一片贴子，说到自己看到梁朝伟的情形，有一次梁朝伟到内地来... (展开)
3993 254 426回应 收起
丁小云 2009-01-16 10:36:30

## 爱人同志如何得到现世的幸福

1997年，王家卫凭借《春光乍泄》一举拿下第50届戛纳电影节最佳导演大奖。 我最欣赏的内地作家朱文曾说王家卫影片里的那些旁白听起来特像一个文学青年在絮叨。但《春光乍泄》显然是一个例外，以往作品中“商标式的王氏高度哲理性语言”在本片中被最大程度地弱化，取而代之的是极... (展开)
2190 230 164回应 收起
北漠 2008-11-10 11:54:20

## 醉时同交欢，醒后各分散。

春光乍泄，Happy Together 中文名字和英文对照之下，立刻觉得中文之博大精深。 既然是Happy Together，那么，有一日黎耀辉和何宝荣在一起不再Happy Together而是甘苦与共，那么，这部电影也就失去了意义。 千百年前，诗仙李白就写出了“醉时同交欢，醒后各分散" 黎耀辉和何宝... (展开)
1437 94 109回应 收起
詹尼金 2009-08-18 08:44:32

## 时隔多年，我好像终于看懂了

这是一个寓言，讲述的是一个人，从发梦、追梦、到梦醒的过程。 这个世界上从来就不曾有过一个叫何宝荣的男人。 他美不胜收，却又捉摸不定，喜怒无常。 他象征了我们每个人心底的梦，求之不得，弃之，却又不舍。 我们都是黎耀辉。 勇气和青春一样，是有保质期的。 等到有一... (展开)
819 51 70回应 收起
阳阳。 2008-03-31 23:28:50

## 亲爱的，我不敢看你的眼睛。

你说：不如我们从头来过。 可是，我转过身去，已经看不到哪里是头，回过身时，你却已不在我身旁。 [我爱着你，在你所不知道的地方。] 深爱的时候，我们害怕被知道自己的爱有多深，害怕自己是那个陷得比较深的，所以我不要看你的眼睛，那样会更加沉沦。 在一起的日... (展开)
762 67 91回应 收起
午后小憩 2008-04-08 21:57:48

## 十年春光 一晌贪欢

这篇影评可能有剧透

本来就打算要在近日重温你所有的影片的。前几日看到林奕华的访问，才知道97年金像奖男主角提名的时候，是发生过一些口角的。 据说当时大多数评委投给梁朝伟，原因是身为非同性恋者，把一个同性恋角色演绎得如此妥帖生动实属难能可贵。你呢，顺理成章的表演自然是得心... (展开)
702 15 49回应 收起
狠狠红 2006-06-21 00:15:56

## Always together, forever apart

（1） 我和何宝荣，两个人纠缠在一起很多年。长而烦琐，让我以为衡量我这一生最好的标尺就是何宝荣。 和他吵架，和他冷战，和他和好，又和他分开。我的这一生，被分裂成很多片断。片断的背景由他描色，我在这背景上存活，明明暗暗，他随意来来来、走走走，对于自己，... (展开)
554 5 19回应 收起
布宜諾斯 2007-10-31 20:14:37

## 春光禁色

【黑与白】 凌晨三四点，大街清冷，空气湿漉漉的，弥漫着寒冷的雾，有通宵营业的小店，。习惯于熬夜，但临近五点头脑便开始发胀，开始麻木且盲目。此时的黎耀辉，正敲打着烟店的窗吧。曾经也有类似的场景属于过我，大概是个凌晨的火车站，暗的街灯，机械地赶着路，目的地还未... (展开)
477 15 53回应 收起

> 更多影评 2782篇

添加新讨论

## 讨论区 · · · · · ·

哪儿可以看《春光乍泄》呢~ | 来自司空念 | 2 回应 | 2022-11-23 23:50:11
《春光乍泄happy together》在西方还真是挺受欢迎的 | 来自艺术家 | 30 回应 | 2022-11-23 16:13:41
找个对象 | 来自菜菜奶爸 |  | 2022-11-23 15:08:10
黎耀辉分手后在街头漫步的地方，是当地的同志区吗？ | 来自星尘往事 | 2 回应 | 2022-11-17 13:55:10
春光乍泄 | 来自I .Zorro |  | 2022-11-17 02:02:21

> 去这部影片的讨论区（全部473条）

## 关于《春光乍泄》的问题 · · · · · · ( 全部46个 )

- 为什么黎耀辉把何宝荣的passport拿走，最后也没还给他？ 9人回答
- 张震演的那个角色到底是不是gay？ 27人回答

> 全部46个问题

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 深情即是一桩悲剧，必得以死来句读。 (眠去)
- 【豆瓣五星电影集中营】(1/3) (影志)
- 文艺女王必修课「华语篇」 (不良生)
- 那些牛叉闪闪的片子 (家庭种菜笔记)

## 谁在看这部电影 · · · · · ·

- 杨坚强
  5分钟前 看过
- BEIER
  7分钟前 想看
- 纱织NaNa
  8分钟前 想看

848486人看过 / 356295人想看

订阅春光乍泄的评论:
feed: rss 2.0